@@ -11,14 +11,11 @@ import click
 
 import great_expectations.exceptions as ge_exceptions
 from great_expectations import DataContext, rtd_url_ge_version
+from great_expectations.cli import toolkit
 from great_expectations.cli.docs import build_docs
 from great_expectations.cli.init_messages import NO_DATASOURCES_FOUND
-from great_expectations.cli.util import (
-    cli_message,
-    cli_message_dict,
-    load_data_context_with_error_handling,
-)
 from great_expectations.cli.mark import Mark as mark
+from great_expectations.cli.util import cli_message, cli_message_dict
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.usage_statistics.usage_statistics import (
     send_usage_message,
@@ -64,9 +61,9 @@ class SupportedDatabases(enum.Enum):
     POSTGRES = 'Postgres'
     REDSHIFT = 'Redshift'
     SNOWFLAKE = 'Snowflake'
+    BIGQUERY = 'BigQuery'
     OTHER = 'other - Do you have a working SQLAlchemy connection string?'
     # TODO MSSQL
-    # TODO BigQuery
 
 
 @click.group()
@@ -84,7 +81,7 @@ def datasource():
 )
 def datasource_new(directory):
     """Add a new datasource to the data context."""
-    context = load_data_context_with_error_handling(directory)
+    context = toolkit.load_data_context_with_error_handling(directory)
     datasource_name, data_source_type = add_datasource(context)
 
     if datasource_name:
@@ -108,28 +105,23 @@ def datasource_new(directory):
     '--directory',
     '-d',
     default=None,
-    help="Datasource to delete"
+    help="The project's great_expectations directory."
 )
-@click.option(
-    "--datasource_name",
-    "-s",
-    help="The site that you want documentation cleaned for. See data_docs section in great_expectations.yml",
-)
-def delete_datasource(directory, datasource_name=None):
-    """Delete data source"""
-    print(datasource_name) 
-    context = load_data_context_with_error_handling(directory)
-    if datasource_name is None:
-        cli_message("<red>{}</red>".format("Datasource name must be a datasource name"))
-        return
+@click.argument("datasource")
+def delete_datasource(directory, datasource):
+    """Delete the datasource specified as an argument"""
+    context = toolkit.load_data_context_with_error_handling(directory)
+    try:
+        context.delete_datasource(datasource)
+    except ValueError:
+        cli_message("<red>{}</red>".format("Datasource {} could not be found".format(datasource)))
+        sys.exit(1)
     else:
-        context.delete_datasource(datasource_name)
-        if context.get_datasource(datasource_name) is None: 
-            cli_message("<green>{}</greem>".format("Datasource deleted successfully."))
-            return True
-        else:
-            cli_message("<red>{}</red>".format("Datasource not deleted"))
-            sys.exit(1)
+        cli_message("<green>{}</green>".format("Datasource deleted successfully."))
+
+    if context.get_datasource(datasource) is None:
+        cli_message("<red>{}</red>".format("Datasource not deleted"))
+        sys.exit(1)
 
 
 @datasource.command(name="list")
@@ -141,7 +133,7 @@ def delete_datasource(directory, datasource_name=None):
 )
 def datasource_list(directory):
     """List known datasources."""
-    context = load_data_context_with_error_handling(directory)
+    context = toolkit.load_data_context_with_error_handling(directory)
     datasources = context.list_datasources()
     datasource_count = len(datasources)
 
@@ -204,7 +196,7 @@ def datasource_profile(datasource, batch_kwargs_generator_name, data_assets, pro
     prompt the user to either specify the list of data assets to profile or to profile all.
     If the limit is not exceeded, the profiler will profile all data assets in the datasource.
     """
-    context = load_data_context_with_error_handling(directory)
+    context = toolkit.load_data_context_with_error_handling(directory)
 
     try:
         if additional_batch_kwargs is not None:
@@ -436,6 +428,10 @@ def _add_sqlalchemy_datasource(context, prompt_for_datasource_name=True):
             if not load_library("snowflake", install_instructions_string="pip install snowflake-sqlalchemy"):
                 return None
             credentials = _collect_snowflake_credentials(default_credentials=credentials)
+        elif selected_database == SupportedDatabases.BIGQUERY:
+            if not load_library("pybigquery", install_instructions_string="pip install pybigquery"):
+                return None
+            credentials = _collect_bigquery_credentials(default_credentials=credentials)
         elif selected_database == SupportedDatabases.OTHER:
             sqlalchemy_url = click.prompt(
                 """What is the url/connection string for the sqlalchemy connection?
@@ -576,6 +572,17 @@ def _collect_snowflake_credentials(default_credentials=None):
 
     return credentials
 
+def _collect_bigquery_credentials(default_credentials=None):
+    sqlalchemy_url = click.prompt(
+"""What is the SQLAlchemy url/connection string for the BigQuery connection?
+(reference: https://github.com/mxmzdlv/pybigquery#connection-string-parameters)
+""",
+        show_default=False).strip()
+    credentials = {
+        "url": sqlalchemy_url
+    }
+
+    return credentials
 
 def _collect_mysql_credentials(default_credentials=None):
     # We are insisting on pymysql driver when adding a MySQL datasource through the CLI
@@ -683,35 +690,6 @@ def _add_spark_datasource(context, passthrough_generator_only=True, prompt_for_d
     return datasource_name
 
 
-# TODO consolidate all the myriad CLI tests into this
-def select_datasource(context, datasource_name=None):
-    msg_prompt_select_data_source = "Select a datasource"
-    msg_no_datasources_configured = "<red>No datasources found in the context. To add a datasource, run `great_expectations datasource new`</red>"
-
-    data_source = None
-
-    if datasource_name is None:
-        data_sources = sorted(context.list_datasources(), key=lambda x: x["name"])
-        if len(data_sources) == 0:
-            cli_message(msg_no_datasources_configured)
-        elif len(data_sources) == 1:
-            datasource_name = data_sources[0]["name"]
-        else:
-            choices = "\n".join(
-                ["    {}. {}".format(i, data_source["name"]) for i, data_source in enumerate(data_sources, 1)])
-            option_selection = click.prompt(
-                msg_prompt_select_data_source + "\n" + choices + "\n",
-                type=click.Choice([str(i) for i, data_source in enumerate(data_sources, 1)]),
-                show_choices=False
-            )
-            datasource_name = data_sources[int(option_selection) - 1]["name"]
-
-    if datasource_name is not None:
-        data_source = context.get_datasource(datasource_name)
-
-    return data_source
-
-
 # TODO consolidate all the myriad CLI tests into this
 def select_batch_kwargs_generator(context, datasource_name, available_data_assets_dict=None):
     msg_prompt_select_generator = "Select batch kwarg generator"
@@ -785,7 +763,7 @@ def get_batch_kwargs(context,
         # the datasource has no batch_kwargs_generators
         available_data_assets_dict = {datasource_name: {}}
 
-    data_source = select_datasource(context, datasource_name=datasource_name)
+    data_source = toolkit.select_datasource(context, datasource_name=datasource_name)
     datasource_name = data_source.name
 
     if batch_kwargs_generator_name is None:
@@ -982,7 +960,7 @@ Enter an SQL query
 
     msg_prompt_enter_data_asset_name = "\nWhich table would you like to use? (Choose one)\n"
 
-    msg_prompt_enter_data_asset_name_suffix = "    Don't see the table in the list above? Just type the SQL query\n"
+    msg_prompt_enter_data_asset_name_suffix = "    Do not see the table in the list above? Just type the SQL query\n"
 
     if additional_batch_kwargs is None:
         additional_batch_kwargs = {}
@@ -1016,9 +994,9 @@ Enter an SQL query
         }
     elif datasource.engine.dialect.name.lower() == "bigquery":
         # bigquery also requires special handling
-        table_name = click.prompt("GE will create a table based on your query to use for "
+        table_name = click.prompt("GE will create a table to use for "
                                   "validation." + os.linesep + "Please enter a name for this table: ",
-                                  default="ge_tmp_" + str(uuid.uuid4())[:8])
+                                  default="SOME_PROJECT.SOME_DATASET.ge_tmp_" + str(uuid.uuid4())[:8])
         temp_table_kwargs = {
             "bigquery_temp_table": table_name,
         }
