@@ -1,8 +1,7 @@
 from abc import ABCMeta, abstractmethod
 
 
-class DataContextKey(object):
-    __metaclass__ = ABCMeta
+class DataContextKey(object, metaclass=ABCMeta):
     """DataContextKey objects are used to uniquely identify resources used by the DataContext.
 
     A DataContextKey is designed to support clear naming with multiple representations including a hashable
@@ -34,3 +33,6 @@ class DataContextKey(object):
 
     def __hash__(self):
         return hash(self.to_tuple())
+
+    def __repr__(self):
+        return self.__class__.__name__ + "::" + "/".join(self.to_tuple())
