@@ -257,20 +257,37 @@ class TupleFilesystemStoreBackend(TupleStoreBackend):
                     key_list.append(key)
 
         return key_list
+   
+    
+    def rrmdir(self, mroot, curpath):
+        """
+        recursively removes empty dirs between curpath and mroot inclusive
+        """
+        try:
+            while not os.listdir(curpath) and os.path.exists(curpath) and mroot!=curpath:
+                f2=os.path.dirname(curpath)
+                os.rmdir(curpath)
+                curpath=f2
+        except (NotADirectoryError, FileNotFoundError):
+            pass
+
 
     def remove_key(self, key):
         if not isinstance(key, tuple):
             key = key.to_tuple()
+
         filepath = os.path.join(
             self.full_base_directory,
             self._convert_key_to_filepath(key)
         )
         path, filename = os.path.split(filepath)
         if os.path.exists(filepath):
-            if shutil.rmtree(self.full_base_directory):
-                return True
+            d_path = os.path.dirname(filepath)
+            os.remove(filepath)
+            self.rrmdir(self.full_base_directory, d_path)
+            return True
         return False
-       
+
     def get_url_for_key(self, key, protocol=None):
         path = self._convert_key_to_filepath(key)
         full_path = os.path.join(self.full_base_directory, path)
@@ -468,8 +485,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         bucket = gcs.get_bucket(self.bucket)
         blob = bucket.blob(gcs_object_key)
         if isinstance(value, str):
-            blob.upload_from_string(value.encode(content_encoding), content_encoding=content_encoding,
-                                    content_type=content_type)
+            blob.upload_from_string(value.encode(content_encoding), content_type=content_type)
         else:
             blob.upload_from_string(value, content_type=content_type)
         return gcs_object_key
@@ -502,12 +518,12 @@ class TupleGCSStoreBackend(TupleStoreBackend):
 
     def remove_key(self, key):
         from google.cloud import storage
-        gcs = storage.Client(self.project)
-        gcs_object_key = self._convert_key_to_filepath(key)
-        bucket = cloudStorageClient.bucket(self.bucket)
+        from gcloud.exceptions import NotFound
+        gcs = storage.Client(project=self.project)
+        bucket = gcs.get_bucket(self.bucket)
         try:
             bucket.delete_blobs(blobs=bucket.list_blobs(prefix=self.prefix))
-        except exceptions.NotFound as e:
+        except NotFound:
             return False
         return True
 
