@@ -19,6 +19,14 @@ class DataContextError(GreatExpectationsError):
     pass
 
 
+class CheckpointError(DataContextError):
+    pass
+
+
+class CheckpointNotFoundError(CheckpointError):
+    pass
+
+
 class StoreBackendError(DataContextError):
     pass
 
